==> xl-react-components-0.18.103.tgz: package/app/xl-react-widget/xl-react-widget-patch-editor/xl-react-widget-patch-editor.js <==
import R from 'ramda';
import React, {useState} from 'react';
import PropTypes from 'prop-types';
import {Panel} from 'react-bootstrap';
import KeyCodes from 'keycode-js';
import {Markup} from 'interweave';
import {XlReactFormItemControl} from '../../xl-react-form/xl-react-form-item-control';
import {localeMessages} from '../../services/locale-service';
import {XlReactWidgetPatchSample} from '../xl-react-widget-patch-sample/xl-react-widget-patch-sample';
import {XlReactWidgetConfirmationDialog}
    from '../xl-react-widget-confirmation-dialog/xl-react-widget-confirmation-dialog';
import RU from '../../utils/ramda-utils';
import {patchType} from './patch-type';
import {XlControlButtonsPanel} from './control-buttons/control-buttons-panel';
import {XlEditorPanel} from './editor-panel/editor-panel';
import {editorActions} from './xl-react-widget-patch-editor-actions';

import './xl-react-widget-patch-editor.less';

const ReactWidgetPatchEditor = (props) => {
    const {
        controlButtonsTooltipMessages,
        description,
        editableSection,
        filePath,
        focusOnEditorPanel,
        handleLineSelected: onLineSelected,
        handleEditableSelectionChange,
        handleModifyingPatch,
        handleRemovingPatch,
        model,
        pristine,
        selectedLines,
        selectedAction,
        selectedPath,
        type
    } = props;

    const [showConfirmationDialog, setShowConfirmationDialog] = useState(false);
    const [nextSelectedLine, setNextSelectedLine] = useState();

    const handleLineSelected = (selected) => {
        if (pristine) {
            onLineSelected(selected);
        } else {
            setNextSelectedLine(selected);
            setShowConfirmationDialog(true);
        }
    };

    const handleClose = (reason) => {
        setShowConfirmationDialog(false);

        if (reason === 'confirm') {
            onLineSelected(nextSelectedLine);
            RU.invoke('onPushPatchChange', [editableSection], props);
        } else if (reason === 'discard') {
            RU.invoke('onDiscardChange', [], props);
        }
    };

    const buttons = [{
        action: 'reject',
        className: 'xl-secondary',
        keyCodes: [KeyCodes.KEY_ESCAPE],
        label: localeMessages.cancelButton
    }, {
        action: 'discard',
        className: 'xl-secondary',
        label: localeMessages.discardButton
    }, {
        action: 'confirm',
        className: 'xl-primary',
        keyCodes: [KeyCodes.KEY_RETURN],
        label: localeMessages.addPatchEntryButton
    }];

    const confirmationDialog = <XlReactWidgetConfirmationDialog
        buttons={buttons}
        dialogClassName={'xl-react-widget-patch-editor-confirmation-dialog'}
        onButtonClick={handleClose}
        show={showConfirmationDialog}
        title={localeMessages.patchDictionaryLostChangesTitle}>
        <Markup content={localeMessages.patchDictionaryLostChangesMessage}/>
    </XlReactWidgetConfirmationDialog>;

    return (
        <XlReactFormItemControl {...({
            controlClass: 'xl-react-widget-patch-editor',
            description
        })}>
            {confirmationDialog}
            <Panel className="patch-editor-panel">
                <Panel.Heading>
                    <div className="path-title">{localeMessages.patchDictionaryPathTitle}:</div>
                    <span className="selected-path">{selectedPath}</span>
                </Panel.Heading>
                <Panel.Body>
                    <XlReactWidgetPatchSample
                        customClassNames={[selectedAction]}
                        filePath={filePath}
                        headerLabel={localeMessages.patchDictionarySamplePanelTitle}
                        model={model}
                        onLineSelected={handleLineSelected}
                        selectedLines={selectedLines}
                    />
                    <XlControlButtonsPanel
                        activeAction={selectedAction}
                        handleModifyingPatch={handleModifyingPatch}
                        handleRemovingPatch={handleRemovingPatch}
                        isPanelActive={!R.isEmpty(selectedLines)}
                        tooltipMessages={controlButtonsTooltipMessages}
                    />
                    <XlEditorPanel
                        focusOnMount={focusOnEditorPanel}
                        model={editableSection}
                        onModelChange={handleEditableSelectionChange}
                        readOnly={R.isEmpty(selectedLines)}
                        type={type}
                    />

                </Panel.Body>
            </Panel>
        </XlReactFormItemControl>
    );
};

ReactWidgetPatchEditor.propTypes = {
    controlButtonsTooltipMessages: PropTypes.object,
    description: PropTypes.string,
    editableSection: PropTypes.string.isRequired,
    filePath: PropTypes.string,
    focusOnEditorPanel: PropTypes.bool,
    handleEditableSelectionChange: PropTypes.func.isRequired,
    handleLineSelected: PropTypes.func.isRequired,
    handleModifyingPatch: PropTypes.func.isRequired,
    handleRemovingPatch: PropTypes.func.isRequired,
    model: PropTypes.string.isRequired,
    onDiscardChange: PropTypes.func,
    onPushPatchChange: PropTypes.func,
    pristine: PropTypes.bool.isRequired,
    selectedAction: PropTypes.oneOf(editorActions),
    selectedLines: PropTypes.arrayOf(PropTypes.string).isRequired,
    selectedPath: PropTypes.string.isRequired,
    type: patchType
};

export const XlReactWidgetPatchEditor = React.memo(ReactWidgetPatchEditor);

==> xl-react-components-0.21.12.tgz: package/app/xl-react-widget/xl-react-widget-patch-editor/xl-react-widget-patch-editor.js <==
import R from 'ramda';
import React, {useState} from 'react';
import PropTypes from 'prop-types';
import {Panel} from 'react-bootstrap';
import * as KeyCodes from 'keycode-js';
import {Markup} from 'interweave';
import {XlReactFormItemControl} from '../../xl-react-form/xl-react-form-item-control';
import {localeMessages} from '../../services/locale-service';
import {XlReactWidgetPatchSample} from '../xl-react-widget-patch-sample/xl-react-widget-patch-sample';
import {XlReactWidgetConfirmationDialog}
    from '../xl-react-widget-confirmation-dialog/xl-react-widget-confirmation-dialog';
import RU from '../../utils/ramda-utils';
import {patchType} from './patch-type';
import {XlControlButtonsPanel} from './control-buttons/control-buttons-panel';
import {XlEditorPanel} from './editor-panel/editor-panel';
import {editorActions} from './xl-react-widget-patch-editor-actions';

import './xl-react-widget-patch-editor.less';

const ReactWidgetPatchEditor = (props) => {
    const {
        controlButtonsTooltipMessages,
        description,
        editableSection,
        filePath,
        focusOnEditorPanel,
        handleLineSelected: onLineSelected,
        handleEditableSelectionChange,
        handleModifyingPatch,
        handleRemovingPatch,
        model,
        pristine,
        selectedLines,
        selectedAction,
        selectedPath,
        type
    } = props;

    const [showConfirmationDialog, setShowConfirmationDialog] = useState(false);
    const [nextSelectedLine, setNextSelectedLine] = useState();

    const handleLineSelected = (selected) => {
        if (pristine) {
            onLineSelected(selected);
        } else {
            setNextSelectedLine(selected);
            setShowConfirmationDialog(true);
        }
    };

    const handleClose = (reason) => {
        setShowConfirmationDialog(false);

        if (reason === 'confirm') {
            onLineSelected(nextSelectedLine);
            RU.invoke('onPushPatchChange', [editableSection], props);
        } else if (reason === 'discard') {
            RU.invoke('onDiscardChange', [], props);
        }
    };

    const buttons = [{
        action: 'confirm',
        className: 'xl-primary pull-right',
        keyCodes: [KeyCodes.KEY_RETURN],
        label: localeMessages.updatePatchEntryButton
    }, {
        action: 'discard',
        className: 'xl-secondary pull-right',
        label: localeMessages.discardButton
    }, {
        action: 'reject',
        className: 'xl-cancel pull-right',
        keyCodes: [KeyCodes.KEY_ESCAPE],
        label: localeMessages.cancelButton
    }];

    const confirmationDialog = <XlReactWidgetConfirmationDialog
        buttons={buttons}
        dialogClassName={'xl-react-widget-patch-editor-confirmation-dialog'}
        onButtonClick={handleClose}
        show={showConfirmationDialog}
        title={localeMessages.patchDictionaryLostChangesTitle}>
        <Markup content={localeMessages.patchDictionaryLostChangesMessage}/>
    </XlReactWidgetConfirmationDialog>;

    return (
        <XlReactFormItemControl {...({
            controlClass: 'xl-react-widget-patch-editor',
            description
        })}>
            {confirmationDialog}
            <Panel className="patch-editor-panel">
                <Panel.Heading>
                    <div className="path-title">{localeMessages.patchDictionaryPathTitle}:</div>
                    <span className="selected-path">{selectedPath}</span>
                </Panel.Heading>
                <Panel.Body>
                    <XlReactWidgetPatchSample
                        customClassNames={[selectedAction]}
                        filePath={filePath}
                        headerLabel={localeMessages.patchDictionarySamplePanelTitle}
                        model={model}
                        onLineSelected={handleLineSelected}
                        selectedLines={selectedLines}
                    />
                    <XlControlButtonsPanel
                        activeAction={selectedAction}
                        handleModifyingPatch={handleModifyingPatch}
                        handleRemovingPatch={handleRemovingPatch}
                        isPanelActive={!R.isEmpty(selectedLines)}
                        tooltipMessages={controlButtonsTooltipMessages}
                    />
                    <XlEditorPanel
                        focusOnMount={focusOnEditorPanel}
                        model={editableSection}
                        onModelChange={handleEditableSelectionChange}
                        readOnly={R.isEmpty(selectedLines)}
                        type={type}
                    />

                </Panel.Body>
            </Panel>
        </XlReactFormItemControl>
    );
};

ReactWidgetPatchEditor.propTypes = {
    controlButtonsTooltipMessages: PropTypes.object,
    description: PropTypes.string,
    editableSection: PropTypes.string.isRequired,
    filePath: PropTypes.string,
    focusOnEditorPanel: PropTypes.bool,
    handleEditableSelectionChange: PropTypes.func.isRequired,
    handleLineSelected: PropTypes.func.isRequired,
    handleModifyingPatch: PropTypes.func.isRequired,
    handleRemovingPatch: PropTypes.func.isRequired,
    model: PropTypes.string.isRequired,
    onDiscardChange: PropTypes.func,
    onPushPatchChange: PropTypes.func,
    pristine: PropTypes.bool.isRequired,
    selectedAction: PropTypes.oneOf(editorActions),
    selectedLines: PropTypes.arrayOf(PropTypes.string).isRequired,
    selectedPath: PropTypes.string.isRequired,
    type: patchType
};

export const XlReactWidgetPatchEditor = React.memo(ReactWidgetPatchEditor);
